value_stream_flutter library
Classes
-
DataStream<
T> - A broadcast Stream with access to the latest emitted value. Does explicitly NOT handle errors to provide a direct and simple access to the value.
-
DataStreamBuilder<
T> - Widget that builds itself based on the latest value a DataStream.
-
EventSnapshot<
T> -
EventStream<
T> - A broadcast Stream with access to the latest emitted value, with error handling.
-
EventStreamBuilder<
T> - Widget that builds itself based on the latest value a EventStream.
-
ValueStream<
T> - Abstract base class for a broadcast Stream with access to the latest emitted value.
Functions
-
isNullable<
T> () → bool - Whether the specified type is nullable.
Typedefs
-
DataWidgetBuilder<
T> = Widget Function(BuildContext context, T value) - Signature for strategies that build widgets based on provided data